@@ -6,6 +6,9 @@
 # LOG:
 # - 16.01.25: Add "mce: [Hardware Error]" syntax
 # - 10.02.25: Add "psi: inconsistent task state" syntax
+# - 30.06.25: Add "uas_eh_abort_handler"
+# - 07.08.25: Add "segfault" + "Code:" messages
+#
 
 #
 # configuration
@@ -14,6 +17,7 @@
 # global
 report="/tmp/report.$$"
 disk_error="/tmp/disk_error.$$"
+soft_error="/tmp/soft_error.$$"
 maxsize=1024768
 headline="System monitor: WARNING"
 use_dmesg="no"
@@ -89,17 +93,17 @@ done
 #fi
 
 #
-# disk/hardware errors
+# Disk/Hardware errors
 #
 
 if [ "$use_dmesg" == "yes" ]; then
-   /usr/bin/dmesg |grep -E 'ata[0-1].00: failed|ata[0-3].00: error|FAILED|Sense Key|Unrecovered|read error|sector|\[Hardware Error\]|Register Dump|inconsistent task state' |grep -v multi |while read -r output; do
+   /usr/bin/dmesg |grep -E 'ata[0-1].00: failed|ata[0-3].00: error|FAILED|Sense Key|Unrecovered|read error|sector|\[Hardware Error\]|Register Dump|inconsistent task state|uas_eh_abort_handler' |grep -v multi |while read -r output; do
       echo "$output" >> $report
       echo "Found error" > $disk_error
    done
 else
    echo "Running user friendly dmesg..."
-   /usr/bin/journalctl --since=-12min --dmesg -o short-monotonic --no-hostname --no-pager |grep -E 'ata[0-1].00: failed|ata[0-3].00: error|FAILED|Sense Key|Unrecovered|read error|sector|\[Hardware Error\]|Register Dump|inconsistent task state' |grep -v multi |while read -r output; do
+   /usr/bin/journalctl --since=-12min --dmesg -o short-monotonic --no-hostname --no-pager |grep -E 'ata[0-1].00: failed|ata[0-3].00: error|FAILED|Sense Key|Unrecovered|read error|sector|\[Hardware Error\]|Register Dump|inconsistent task state|uas_eh_abort_handler' |grep -v multi |while read -r output; do
       echo "$output" >> $report
       echo "Found error" > $disk_error
    done
@@ -112,7 +116,32 @@ if [ -f $disk_error ]; then
    printf '\n\n' >> $report
    echo "Harddrive error(s) found!" |systemd-cat -p warning -t "$(basename "$0")"
 fi
-    
+
+#
+# Software errors
+#
+
+if [ "$use_dmesg" == "yes" ]; then
+   /usr/bin/dmesg |grep -E 'segfault|Code:' |grep -v multi |while read -r output; do
+      echo "$output" >> $report
+      echo "Found error" > $soft_error
+   done
+else
+   echo "Running user friendly dmesg..."
+   /usr/bin/journalctl --since=-12min --dmesg -o short-monotonic --no-hostname --no-pager |grep -E 'segfault|Code:' |grep -v multi |while read -r output; do
+      echo "$output" >> $report
+      echo "Found error" > $soft_error
+   done
+fi
+   
+if [ -f $soft_error ]; then
+   if [ "$use_dmesg" == "yes" ]; then
+      /usr/bin/dmesg --clear
+   fi
+   printf '\n\n' >> $report
+   echo "Software error(s) found!" |systemd-cat -p warning -t "$(basename "$0")"
+fi
+ 
 #
 # memory
 #
@@ -225,6 +254,7 @@ fi
 
 rm $report
 rm $disk_error 2>/dev/null
+rm $soft_error 2>/dev/null
 
 echo "$(basename "$0") finished." |systemd-cat -p info -t "$(basename "$0")"
 
